@@ -11,7 +11,7 @@
 	int dirfd = at_get_fd(s); \
 	\
 	s = argv[i++]; \
-	char *file = s; \
+	const char *file = f_get_file(s); \
 	\
 	s = argv[i++]; \
 	int flags = f_get_flags(s); \
